==> dojo-1.10.6.tgz: package/cldr/nls/sr/indian.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "ове суботе",
	"field-sat-relative+1": "следеће суботе",
	"field-dayperiod": "пре подне/поподне",
	"field-sun-relative+-1": "прошле недеље",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-minute": "минут",
	"field-day-relative+-1": "јуче",
	"field-weekday": "дан у недељи",
	"field-day-relative+-2": "прекјуче",
	"field-era": "ера",
	"field-hour": "час",
	"field-sun-relative+0": "ове недеље",
	"field-sun-relative+1": "следеће недеље",
	"field-wed-relative+-1": "прошле среде",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"eraAbbr": [
		"САКА"
	],
	"field-day-relative+2": "прекосутра",
	"field-tue-relative+0": "овог уторка",
	"field-zone": "зона",
	"field-tue-relative+1": "следећег уторка",
	"field-week-relative+-1": "Прошле недеље",
	"field-year-relative+0": "Ове године",
	"field-year-relative+1": "Следеће године",
	"field-sat-relative+-1": "прошле суботе",
	"field-year-relative+-1": "Прошле године",
	"field-year": "година",
	"field-fri-relative+0": "овог петка",
	"field-fri-relative+1": "следећег петка",
	"field-week": "недеља",
	"field-week-relative+0": "Ове недеље",
	"field-week-relative+1": "Следеће недеље",
	"field-month-relative+0": "Овог месеца",
	"field-month": "месец",
	"field-month-relative+1": "Следећег месеца",
	"field-fri-relative+-1": "прошлог петка",
	"field-second": "секунд",
	"field-tue-relative+-1": "прошлог уторка",
	"field-day": "дан",
	"field-mon-relative+0": "овог понедељка",
	"field-mon-relative+1": "следећег понедељка",
	"field-thu-relative+0": "овог четвртка",
	"field-second-relative+0": "сада",
	"field-thu-relative+1": "следећег четвртка",
	"field-wed-relative+0": "ове среде",
	"months-format-wide": [
		"Чаитра",
		"Ваисака",
		"Јиаиста",
		"Асада",
		"Сравана",
		"Бадра",
		"Асвина",
		"Картика",
		"Аргајана",
		"Пауза",
		"Мага",
		"Фалгуна"
	],
	"field-wed-relative+1": "следеће среде",
	"field-month-relative+-1": "Прошлог месеца",
	"field-thu-relative+-1": "прошлог четвртка"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/sr/indian.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "у суботу",
	"field-sat-relative+1": "следеће суботе",
	"field-dayperiod": "пре подне/по подне",
	"field-sun-relative+-1": "прошле недеље",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-minute": "минут",
	"field-day-relative+-1": "јуче",
	"field-weekday": "дан у недељи",
	"field-day-relative+-2": "прекјуче",
	"field-era": "ера",
	"field-hour": "сат",
	"field-sun-relative+0": "у недељу",
	"field-sun-relative+1": "следеће недеље",
	"field-wed-relative+-1": "прошле среде",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"eraAbbr": [
		"САКА"
	],
	"field-day-relative+2": "прекосутра",
	"field-tue-relative+0": "у уторак",
	"field-zone": "временска зона",
	"field-tue-relative+1": "следећег уторка",
	"field-week-relative+-1": "прошле недеље",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-sat-relative+-1": "прошле суботе",
	"field-year-relative+-1": "прошле године",
	"field-year": "година",
	"field-fri-relative+0": "у петак",
	"field-fri-relative+1": "следећег петка",
	"field-week": "недеља",
	"field-week-relative+0": "ове недеље",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+0": "овог месеца",
	"field-month": "месец",
	"field-month-relative+1": "следећег месеца",
	"field-fri-relative+-1": "прошлог петка",
	"field-second": "секунд",
	"field-tue-relative+-1": "прошлог уторка",
	"field-day": "дан",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-thu-relative+0": "у четвртак",
	"field-second-relative+0": "сада",
	"field-thu-relative+1": "следећег четвртка",
	"field-wed-relative+0": "у среду",
	"months-format-wide": [
		"Чаитра",
		"Ваисака",
		"Јиаиста",
		"Асада",
		"Сравана",
		"Бадра",
		"Асвина",
		"Картика",
		"Аргајана",
		"Пауза",
		"Мага",
		"Фалгуна"
	],
	"field-wed-relative+1": "следеће среде",
	"field-month-relative+-1": "прошлог месеца",
	"field-thu-relative+-1": "прошлог четвртка"
}
//end v1.x content
);
